spacepy.toolbox.bin_edges_to_center — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »

# spacepy.toolbox.bin_edges_to_center

`spacepy.toolbox.` `bin_edges_to_center`(edges)

  Convert a list of bin edges to their centers

  Given a list of edge values for a set of bins, finds the center of each bin. (start of bin n+1 is assumed to be end of bin n).

  Center of bin n is arithmetic mean of the edges of the adjacent bins.

  Parameters: | edges : list list of edge values for bins
  Returns: | out : numpy.ndarray array of centers for bins **note: returned array will be one element shorter than edges** :

  Examples

      >>> import spacepy.toolbox as tb
      >>> tb.bin_center_to_edges([1,2,3])
      [0.5, 1.5, 2.5, 3.5]

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »